@@ -22,7 +22,7 @@
 
 #include "mpi-dft.h"
 #include "mpi-transpose.h"
-#include "dft.h"
+#include "dft/dft.h"
 
 typedef struct {
      solver super;
